# sterope

Sterope is a python3 package that implement a method based on the Dynamic
Influence Network (https://www.ncbi.nlm.nih.gov/pubmed/28866584) to analyze the
sensitivity of parameter values in the response of a Rule-Based Model written in
kappa (https://kappalanguage.org/)

The plan to add methods into Pleiades (https://github.com/glucksfall/pleiades)
includes a parameterization employing a Particle Swarm Optimization protocol and
other analysis methods that are typical of frameworks like Ordinary Differential
Equations. You could write us if you wish to add methods into pleione or aid in
the development of them.
